pub struct Draft202012 {
pub syntax: Option<String>,
pub refs: Vec<String>,
pub dynamic_refs: Vec<String>,
pub anchors: Vec<String>,
}Fields
syntax: Option<String>The $schema keyword is used to declare which dialect of JSON Schema the
schema was written for. The value of the $schema keyword is also the
identifier for a schema that can be used to verify that the schema is valid
according to the dialect $schema identifies. A schema that describes another
schema is called a “meta-schema”.
$schema applies to the entire document and must be at the root level. It
does not apply to externally referenced ($ref, $dynamicRef) documents. Those
schemas need to declare their own $schema.
If $schema is not used, an implementation might allow you to specify a
value externally or it might make assumptions about which specification
version should be used to evaluate the schema. It’s recommended that all
JSON Schemas have a $schema keyword to communicate to readers and tooling
which specification version is intended.
see also:
- https://json-schema.org/understanding-json-schema/reference/schema.html#schema
- https://json-schema.org/draft/2020-12/json-schema-core.html#rfc.section.8.1.1
refs: Vec<String>dynamic_refs: Vec<String>anchors: Vec<String>Trait Implementations
Sourceimpl Clone for Draft202012
impl Clone for Draft202012
Sourcefn clone(&self) -> Draft202012
fn clone(&self) -> Draft202012
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Draft202012
impl Debug for Draft202012
Sourceimpl<'de> Deserialize<'de> for Draft202012
impl<'de> Deserialize<'de> for Draft202012
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for Draft202012
impl PartialEq for Draft202012
Sourcefn eq(&self, other: &Draft202012) -> bool
fn eq(&self, other: &Draft202012) -> bool
self and other values to be equal, and is used by ==.